@@ -13,10 +13,6 @@
 #ifndef QCITATION_H
 #define QCITATION_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "Qt2Base.h"
 
 class QListBox;
