@@ -12,10 +12,6 @@
 #ifndef TEX_STRINGS
 #define TEX_STRINGS
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 // this file should perhaps be split into even smaler parts
 
 ///
